# StringEditor::Plugin.pm by Michael Herger oct 2005
#
# This code is derived from code with the following copyright message:
#
# SliMP3 Server Copyright (C) 2001 Sean Adams, Slim Devices Inc.
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License,
# version 2.
#
# Changelog
# 1.52 - add Italian translation (thanks Riccardo)
# 1.51 - encode html entities in EN string when translating
# 1.50 - improve 6.5 compatibility: .slimserver-strings.txt has been replaced with slimserver-strings.txt
#      - add 6.5 optimized skin
#      - sanity check search expression
#      - add "All Strings" link to list all strings
# 1.46 - add Dutch translation - thanks Willem!
# 1.45 - make it slimserver 6.5 compatible
#      - another try to fix utf8 encoding isues
# 1.43 - Slim::Utils::Unicode::utf8decode_guess() the entered strings
# 1.42 - reset Slim::Button::Plugins::plugins cache - or the plugins's strings won't be read
# 1.41 - move strings to Plugin.pm
# 1.4  - using AsyncHTTP for upload of files - fixes problems with large uploads
#      - added czech translation (Thanks Roman!)
# 1.32 - filter some incorrect string identifiers
#      - add a link to the manual upload page
# 1.31 - fix a problem with the new plugin interface
# 1.3  - add option to filter out plugins' strings
# 1.2  - profit from recent changes in Slim/Utils/Strings, remove string initialization stuff
# 1.1  - add warning for perl 5.6 users
# 1.0  - add support for non-blocking http requests
#      - add setting: flush strings when storing or not (prevent problems with plugins)
#      - add "Changelog": simplified access to SVN repository
# 0.92 - add spanish translation (Thanks Néstor!)
# 0.91 - add skins
#      - add support for proxy
# 0.9  - first release

use strict;

package Plugins::StringEditor::Plugin;

use Slim::Utils::Strings qw(string);
use vars qw($VERSION);
$VERSION = substr(q$Revision: 1.52 $,10);

my $customStringsFile = Slim::Utils::Prefs::preferencesPath() . '/slimserver-strings.txt';
$::d_plugins && Slim::Utils::Misc::msg("$customStringsFile\n");

my $uploadURL = 'http://www.herger.net/slim/uploadStrings.cgi';
#$uploadURL = 'http://www.herger.net/slim/uploadStrings2.cgi';
my $svnBaseURL = 'http://svn.slimdevices.com';
my $svnURL = '/trunk/server/strings.txt';

sub getDisplayName {
	return 'PLUGIN_STRINGEDITOR_HELPER';
}

# Web pages

sub webPages {
    my %pages = (
        'index\.html' => \&handleWebIndex,
        'custom-strings\.txt' => \&showStringsFile
    );

    return (\%pages, 'index.html');
}

sub handleWebIndex {
	my ($client, $params, $callback, $httpClient, $response) = @_;
	my $strings = Slim::Utils::Strings::hashref_of_strings();
	$params->{'foundstrings'} = '';

	# disable some function for english speaking users
	$params->{'notranslator'} = (getLanguage() eq failsafeLanguage());

	if (defined($params->{'param0'})) {
		# create new language
		if (($params->{'param0'} eq string('SAVE')) && (defined($params->{'param1'}) && ($params->{'param1'} eq 'newlanguage'))
			&& defined($params->{'param2'}) && defined($params->{'param3'})) {
			addNewLanguage($params, $strings);
		}
	
		# save changed string to custom strings file
		if (($params->{'param0'} eq string('SAVE')) && (defined($params->{'param5'}) && ($params->{'param5'} eq 'editstring'))
			&& defined(string($params->{'param1'})) && defined($params->{'param4'})) {
			saveTranslation($params);
		}

		# don't print string names even in translator mode - after all we're working on it...
		my $translatorMode = Slim::Utils::Prefs::get('plugin-stringeditor-translatormode');
		Slim::Utils::Prefs::set('plugin-stringeditor-translatormode', 0);

		# look for strings that are not yet translated
		if ($params->{'param0'} eq 'emptystrings') {
			findEmptyStrings($params, $strings);
		}
		elsif ($params->{'param0'} eq 'allstrings') {
			$params->{'param0'} = 'search';
			$params->{param1} = '.';
			findStringOrTranslation($params, $strings);
		}
		# keyword search
		elsif (($params->{'param0'} eq 'search') && (defined $params->{param1})) {
			findStringOrTranslation($params, $strings);
		}
		# edit string
		elsif (($params->{'param0'} eq 'edit') && (defined string($params->{'param1'}))) {
			editString($params);
		}
		# create new language
		elsif ($params->{'param0'} eq 'newlanguage') {
			$params->{'newlanguage'} = 1;
		}
		# display custom strings file
		elsif ($params->{'param0'} eq 'showstrings') {
			showStringsFile($client, $params);
		}
		# send changes to slimdevices
		elsif ($params->{'param0'} eq 'sendstrings') {
			if (sendStrings($client, $params, $callback, $httpClient, $response)) {
				return undef;
			}
			else {
				$params->{'param3'} = Slim::Utils::Misc::settingsDiagString() . "\n<p>";
			}
		}
		# remove all changes...
		elsif ($params->{'param0'} eq 'resetstrings') {
			resetStrings($params);
		}
		# display changelog from svn.slimdevices.com
		elsif ($params->{'param0'} eq 'changelog') {
			showChangelog($params);
		}
		# do some settings
		elsif ($params->{'param0'} eq 'settings') {
			Slim::Utils::Prefs::set('plugin-stringeditor-translatormode', $translatorMode);
			$translatorMode = doSettings($params);
		}
		else {
			$params->{'searchstring'} = 1;
		}

		# restore translator mode
		Slim::Utils::Prefs::set('plugin-stringeditor-translatormode', $translatorMode);
	}
	else {
		$params->{'searchstring'} = 1;
	}
	$params->{'translatormode'} = Slim::Utils::Prefs::get('plugin-stringeditor-translatormode');
	$params->{'ignoreplugins'} = Slim::Utils::Prefs::get('plugin-stringeditor-noplugins');
	
	if ($] < 5.008) {
		$params->{'perl56'} = string('PLUGIN_STRINGEDITOR_WARNING_PERL56');
	}

	return Slim::Web::HTTP::filltemplatefile('plugins/StringEditor/' . ($::VERSION ge '6.5' ? 'index65.html' : 'index.html'), $params);
}

sub findStringOrTranslation {
	my $params = shift;
	my $strings = shift;

	my @foundStrings;
	
	my $keyword = $params->{'param1'};

	$keyword = '.' if ($keyword eq '*');
	
	# sanity check the search expression...
	eval "'' =~ /$keyword/";
	if ($@) {
		$params->{'msg'} = "'$keyword': " . string('PLUGIN_STRINGEDITOR_BAD_SEARCH');
		$params->{'searchstring'} = 1;
		return;	
	}
	
	$params->{'foundstrings'} = '';
	$params->{'searchstring'} = 1;

	foreach (sort(keys(%$strings))) {
		my $stringname = uc($_);

		next if ($stringname =~ /\s/);

		my $allstrings = $stringname . '|' . string($stringname, getLanguage(), 1) . '|' . string($stringname, failsafeLanguage(), 1);

		if ($allstrings =~ /$keyword/i && not (Slim::Utils::Prefs::get('plugin-stringeditor-noplugins') && $stringname =~ /\W*PLUGIN_/i)) {
			my $enString = string($stringname, failsafeLanguage(), 1);
			my $foreignString = (string($stringname, getLanguage(), 1) ne string($stringname, failsafeLanguage(), 1) ? string($stringname, getLanguage(), 1) : '');

			if ($enString || $foreignString) {
				push @foundStrings, { 
					'stringname' => $stringname, 
					'enstring' => $enString,
					'foreignstring' => $foreignString
				};
				$params->{'foundstrings'} = 1;
			}
		}
	}
	if ($params->{'foundstrings'} eq '') {
		$params->{'msg'} = "'$keyword': " . string('PLUGIN_STRINGEDITOR_STRING_NOT_FOUND');
		$params->{'searchstring'} = 1;
	}
	else {
		$params->{'foundStringsA'} = \@foundStrings;
	}
}


sub findEmptyStrings {
	my $params = shift;
	my $strings = shift;
	
	my @foundStrings;

	$params->{'foundstrings'} = '';
	$params->{'emptystrings'} = 1;
	
	foreach (sort(keys(%$strings))) {
		my $stringname = uc($_);
		
		next if ($stringname =~ /\s/);

		if (!stringExists($stringname, getLanguage(), $strings, 1) 
			&& stringExists($stringname, failsafeLanguage(), $strings)
			&& not (Slim::Utils::Prefs::get('plugin-stringeditor-noplugins') && $stringname =~ /\W*PLUGIN_/i)) {
			push @foundStrings, { 
				'stringname' => $stringname, 
				'enstring' => string($stringname, failsafeLanguage(), 1)
			};
			$params->{'foundstrings'} = 1;
		}
	}
	if ($params->{'foundstrings'} eq '') {
		$params->{'msg'} = string('PLUGIN_STRINGEDITOR_NO_EMPTY_STRINGS');
	}
	else {
		$params->{'foundStringsA'} = \@foundStrings;
	}
}


sub editString {
	my $params = shift;
	
	if (defined(string($params->{'param1'}, getLanguage(), 1))) {
		$params->{'editstring'} = 1;
		$params->{'enstring'} = string($params->{'param1'}, failsafeLanguage(), 1);
		if ((uc($params->{'param2'}) eq 'SEARCH') && (string($params->{'param1'}, getLanguage(), 1) ne string($params->{'param1'}, failsafeLanguage(), 1))) { 
			$params->{'foreignstring'} = string($params->{'param1'}, getLanguage(), 1); 
		}
		else { $params->{'foreignstring'} = ''; }
	}
	else {
		$params->{'msg'} = string('PLUGIN_STRINGEDITOR_STRING_NOT_FOUND');
		$params->{'searchstring'} = 1;
	}
}


sub saveTranslation {
	my $params = shift;
	my $language = getLanguage();
	# do not store if it is equal to the english or it's original translation
	if (string($params->{'param1'}) ne $params->{'param4'}) {
		storeStringToFile($params->{'param1'}, $params->{'param4'});

		# initialize the strings
		initStrings();
	}

	# restore last search's parameters
	$params->{'param0'} = $params->{'param2'};
	$params->{'param1'} = $params->{'param3'};
}


sub storeStringToFile {
	my ($stringname, $newtranslation, $language) = @_;
	$language = getLanguage() if (!defined($language));
	$stringname = uc($stringname);
	my $strings = '';

	# remove newline & co.
	$newtranslation = Slim::Utils::Unicode::utf8decode_guess($newtranslation);
	$newtranslation =~ s/\s/ /sig;

	$strings = getCustomStringsFile();

	# verify if the string has been changed, added, or removed
	# get the string with all its translations from the original file
	if ($strings && ($strings =~ /(^$stringname\s.*?)(^[^\t]+|\z)/smi)) {
		my $translations = $1;

		# if translation is empty, remove it from the file
		if (! $newtranslation) {
 			$translations =~ s/^(\t$language\t.+?(\n|\z))//ism;
		}

		# try to replace an existing string
		elsif (! ($translations =~ s/^(\t$language\t).+?$/$1$newtranslation/ism)) {
			# ... or simply add it
			$translations =~ s/(^$stringname\n)/$1\t$language\t$newtranslation\n/ism;
		}
		$translations = sortTranslations($translations);

		# let's get the whole string replaced in the original file
		$strings =~ s/(^$stringname\s.*?)(^[^\t]+|\z)/$translations$2/smi;
	}
	# file did not exist yet or was empty
	else {
		$strings .= "\n$stringname\n\t$language\t$newtranslation";
	}

	$strings = cleanupStrings($strings);

	# ...somebody tell me why I may not use :utf8 as output filter...
#	open(STRINGS, ">$customStringsFile") || Slim::Utils::Misc::msg("Could not open $customStringsFile for writing: $!\n");
	if ($] > 5.007) {
		open(STRINGS, '>:utf8', $customStringsFile) || Slim::Utils::Misc::msg("Could not open $customStringsFile for writing: $!\n");
		binmode STRINGS, ":utf8";
	}
	else {
		open(STRINGS, $customStringsFile) || Slim::Utils::Misc::msg("Could not open $customStringsFile for writing: $!\n");
	}
	print STRINGS $strings;
	close(STRINGS);
}


sub cleanupStrings {
	my $strings = shift;
	# remove leading/trailing empty lines
	$strings =~ s/^\s+//s;
	$strings =~ s/\s+$//s;
	
	# remove surplus empty lines
	$strings =~ s/\n[\s\n]*\n/\n\n/mg;
	return "$strings\n";
}


# sort the different translations for a string according to their language code
sub sortTranslations {
	my @strings = split("\n", shift);
	my $stringname = splice(@strings, 0, 1);

	# if there's no more string, discard $stringname, too
	if ($#strings < 0) {
		return '';
	}
	else {
		@strings = sort(@strings);
		return "$stringname\n" . join("\n", @strings) . "\n";
	}
}


sub addNewLanguage {
	my $params = shift;
	my $strings = shift;
	$params->{'param2'} = uc($params->{'param2'});

	# verify if language already exists:
	if (defined($$strings{'LANGUAGE_CHOICES'}->{$params->{'param2'}})) {
		$params->{'msg'} = $params->{'param2'} . string('COLON') . ' ' . string('PLUGIN_STRINGEDITOR_LANGUAGE_ALREADY_EXISTS');
		$params->{'param0'} = 'newlanguage';
	}
	else {
		# store identifier and name
		storeStringToFile('LANGUAGE_CHOICES', $params->{'param3'}, $params->{'param2'});

		# store credits (if defined)
		if (defined($params->{'param4'})) {
			storeStringToFile('CREDITS', $params->{'param4'}, $params->{'param2'});
		}

		# initialize the strings
		initStrings();

		# change to newly added language
		Slim::Utils::Strings::setLanguage($params->{'param2'});

		$params->{'msg'} = string('PLUGIN_STRINGEDITOR_LANGUAGE_ADDED') . '<br>' . $params->{'param2'} . string('COLON') . ' ' . $params->{'param3'};

		# restore last search's parameters
		$params->{'param0'} = '';
		$params->{'param1'} = '';
	}
}


sub showStringsFile {
	my ($client, $params) = @_;
	$params->{'showstrings'} = getCustomStringsFile();
	if (not $params->{'showstrings'}) {
		$params->{'showstrings'} = string('PLUGIN_STRINGEDITOR_EMPTY_FILE');
		$params->{'msg'} = string('PLUGIN_STRINGEDITOR_NO_FILE');
	};
	$params->{'Content-Type'} = 'text/plain; charset=utf-8';
	return Slim::Web::HTTP::filltemplatefile('plugins/StringEditor/strings.txt', $params);
}


sub resetStrings {
	my $params = shift;
	$params->{'resetstrings'} = 1;

	# confirmed...
	if (defined($params->{'param1'})  && ($params->{'param1'} eq '1')) {
		unlink $customStringsFile if (-e $customStringsFile);
		initStrings();
		$params->{'param1'} = '';
		$params->{'msg'} = string('PLUGIN_STRINGEDITOR_FILE_REMOVED');
		$params->{'searchstring'} = 1;
		$params->{'resetstrings'} = 0;
	}
	# no translation to delete
	elsif (! -e $customStringsFile) {
		$params->{'msg'} = string('PLUGIN_STRINGEDITOR_NO_FILE');
		$params->{'noform'} = 1;
	}
}


sub sendStrings {
	my ($client, $params, $callback, $httpClient, $response) = @_;
	$params->{'sendstrings'} = 1;
	my $sent = 0;
	
	# roughly test mail address...
	if (defined($params->{'param1'}) && $params->{'param1'} && defined($params->{'param2'}) && defined($params->{'param4'}) && ($params->{'param2'} =~ /[\w\.-]+\@[\w\.-]{2,}\.\w{2,3}$/)) {
		my $http = Slim::Networking::SimpleAsyncHTTP->new(\&uploadOK, \&uploadError, 
			{
				client => $client, 
				params => $params, 
				callback => $callback, 
				httpClient => $httpClient, 
				response => $response
			});

		use URI::Escape qw(uri_escape_utf8 uri_escape);
		my $request = 'userName=' . uri_escape($params->{'param1'});
		$request .= '&userMail=' . $params->{'param2'};
		$request .= '&userLanguage=' . uri_escape(getLanguage());
		$request .= '&userComment=' . uri_escape($params->{'param3'});
		$request .= '&submit=1';
		$request .= '&fileName=' . $customStringsFile;
		$request .= '&fileContent=' . uri_escape_utf8(getCustomStringsFile());

		$http->post($uploadURL, 'Content-Type' => 'application/x-www-form-urlencoded', $request);
		$sent = 1;
		$params->{'param4'} = undef;
	}
	# no translation to send
	elsif (! -e $customStringsFile) {
		$params->{'msg'} = string('PLUGIN_STRINGEDITOR_NO_FILE');
		$params->{'noform'} = 1;
	}
	# if it was called from the form, but without data, print error message
	elsif (defined($params->{'param4'})) {
		$params->{'msg'} = string('PLUGIN_STRINGEDITOR_VERIFY_MAIL');
	}
	return $sent;
}

sub uploadOK {
	my $http = shift;
	my $params = $http->params();
    my $html = $http->content();

	$::d_plugins && Slim::Utils::Misc::msg("StringEditor upload says: $html\n");
	# has the file correctly been uploaded?
    if ($html && ($html =~ /thank you/i)) {
		$params->{params}->{'sendstrings'} = 0;
		$params->{params}->{'msg'} = string('PLUGIN_STRINGEDITOR_THANK_YOU');
	}
	else {
		$params->{params}->{'sendstrings'} = 1;
		$params->{params}->{'msg'} = string('PLUGIN_STRINGEDITOR_SEND_ERROR');
	}

	createAsyncWebPage($params);
}

sub uploadError {
	my $http = shift;
	my $params = $http->params();

	$::d_plugins && Slim::Utils::Misc::msg("StringEditor upload has failed.\n");

	$params->{params}->{'sendstrings'} = 1;
	$params->{params}->{'msg'} = string('PLUGIN_STRINGEDITOR_SEND_ERROR');
	createAsyncWebPage($params);
}

sub createAsyncWebPage {
	my $params = shift;
	# create webpage if we were called by the web interface

	if ($params->{httpClient}) {
		my $output = handleWebIndex($params->{client}, $params->{params}, $params->{callback}, $params->{httpClient}, $params->{response});

		my $current_player;
		if (defined($params->{client})) {
			$current_player = $params->{client}->id();
		}
		$params->{callback}->($current_player, $params->{params}, $output, $params->{httpClient}, $params->{response});
	}
}


sub showChangelog {
	my $params = shift;
	
	# This makes a non-blocking request to the remote server.
	my $http = Slim::Player::Protocols::HTTP->new({ 'url' => "$svnBaseURL$svnURL", 'create' => 0 });
    
    my $html;
    if (defined $http) {
		$html = $http->content();
		$http->close();
    }
    
    if ($html) {
		$html =~ /No default branch\s*?<br>(.*?Initial Revision\W*<\/pre>)/si;
		$html = $1;
		$html =~ s/^<br>File length.*?b>$//mig;

		# remove some of the links...
		$html =~ s/^\s*[-(].*?$//mig;
		
		# replace URLs
		$html =~ s/(href=")\?/target="SVN" $1$svnBaseURL$svnURL\?/sig;
		$html =~ s/(href=")\//target="SVN" $1$svnBaseURL\//sig;

    	$params->{'changelog'} = $html;
    }
    else {
    	$params->{'changelog'} = 'timeout?';
    }
}


sub doSettings {
	my $params = shift;
	$params->{'msg'} = '';

	# translator mode
	if (defined($params->{'param1'})) {
		if (($params->{'param1'} eq '0')) {
			$params->{'msg'} = string('PLUGIN_STRINGEDITOR_MODE_OFF');
			Slim::Utils::Prefs::set('plugin-stringeditor-translatormode', '0');
		}
		else {
			$params->{'msg'} = string('PLUGIN_STRINGEDITOR_MODE_ON');
			Slim::Utils::Prefs::set('plugin-stringeditor-translatormode', '1');
		}
		$params->{'msg'} .= '<br>';
	}
	
	# ignore plugins
	if (defined($params->{'param2'})) {
		if (($params->{'param2'} eq '0')) {
			$params->{'msg'} .= string('PLUGIN_STRINGEDITOR_NOPLUGINS_OFF');
			Slim::Utils::Prefs::set('plugin-stringeditor-noplugins', '0');
		}
		else {
			$params->{'msg'} .= string('PLUGIN_STRINGEDITOR_NOPLUGINS_ON');
			Slim::Utils::Prefs::set('plugin-stringeditor-noplugins', '1');
		}
	}
	
	$params->{'settings'} = 1;
	return Slim::Utils::Prefs::get('plugin-stringeditor-translatormode');
}

sub initStrings {
	if ($::VERSION ge '6.5') {
		Slim::Utils::PluginManager::clearPlugins();
		Slim::Utils::Strings::init();
		Slim::Utils::PluginManager::initPlugins();
		Slim::Web::Setup::initSetup();
	}
	else {
		Slim::Buttons::Plugins::clearPlugins();
		Slim::Utils::Strings::init();
		Slim::Buttons::Plugins::initPlugins();
		Slim::Web::Setup::initSetup();
	}
}


sub stringExists {
	my $stringname = uc(shift) || return 0;
	my $language   = shift || getLanguage();
	my $strings	   = shift;
	my $nofailover = shift;

	my $originalexists = $$strings{$stringname}->{$language} || 0;
	my $failoverexists = $$strings{$stringname}->{failsafeLanguage()} || 0;
	return ($originalexists || ($nofailover ? 0 : $failoverexists));
}


sub getCustomStringsFile {
	my $strings = '';
	if (-e $customStringsFile) {
		if ($] > 5.007) {
			open(STRINGS, '<:utf8', $customStringsFile) || Slim::Utils::Misc::msg("Could not open $customStringsFile for reading: $!\n");	
		}
		else {
			open(STRINGS, $customStringsFile) || Slim::Utils::Misc::msg("Could not open $customStringsFile for reading: $!\n");	
		}
		$strings = join('', <STRINGS>);
		close STRINGS;
	}
	return $strings;
}


sub failsafeLanguage() {
	return Slim::Utils::Strings::failsafeLanguage();
}


sub getLanguage() {
	Slim::Utils::Strings::getLanguage();
}


sub strings { 
	return q^
PLUGIN_STRINGEDITOR_HELPER
	CZ	Editor popisků pro SlimServer (Nástroj pro překládání)
	DE	SlimServer Textbearbeitungs Werkzeug
	EN	SlimServer String Editor (aka Translation Helper)
	ES	Editor de cadenas de texto de SlimServer (alias Ayudante de Traducción)
	IT	SlimServer String Editor (cioe' Aiuto Traduttore)
	NL	SlimServer String editor (Vertaalhulp)

PLUGIN_STRINGEDITOR_IDENTIFIER
	CZ	Identifikátor
	DE	Identifier
	EN	Identifier
	ES	Identificador
	IT	Identificativo
	NL	Identifier

PLUGIN_STRINGEDITOR_DEFAULT_STRING
	CZ	Výchozí popisek
	DE	Vorgabewert
	EN	Default string
	ES	Cadena por defecto
	IT	Stringa di default
	NL	Standaard string

PLUGIN_STRINGEDITOR_TRANSLATED_STRING
	CZ	Překlad popisku
	DE	Übersetzung
	EN	Translated string
	ES	Cadena traducida
	IT	Stringa tradotta
	NL	Vertaalde string

PLUGIN_STRINGEDITOR_SEARCH
	CZ	Vyhledávání
	DE	Suchen
	EN	Search
	ES	Buscar
	IT	Cerca
	NL	Zoeken

PLUGIN_STRINGEDITOR_SEARCH_DESC
	CZ	Toto klíčové slovo prohledává slova ve jménech popisků, v překladu defaultního jazyka (English) a v aktuálním překladu. Při vyhledávání nezáleží na velikosti písmen.  Vyhledání např.  "tag" vrátí hodnotu "TAG" nebo "čte mp3 Tagy".
	DE	Die Suchfunktion erlaubt es, Texte nach Stichworten zu suchen. Das Stichwort wird dabei in Stringnamen, Original-Text (Englisch) und der aktuellen Sprache gesucht. Die Suche unterscheidet nicht zwischen Gross- und Kleinschreibung. So findet z.B. die Suche nach "tag" sowohl den Stringnamen "TAGVERSION", wie auch z.B. "Read MP3 Tags" oder "Frohe Feiertage!".
	EN	The keyword search finds keywords in string names, the default language's string (english), and the current system's language's texts. The search is case insensitive. A search for eg. "tag" will find "TAGVERSION" as well as "Read MP3 Tags" or the german "Frohe Feiertage!".
	ES	La búsqueda por palabras busca esas palabras en los nombres de las cadenas, en el valor de la cadena por defecto (inglés) y en los textos del idioma actual del sistema. La búsqueda no respeta mayúsculas ni minúsculas. Por ejmplo, una búsqueda por "tag" encontrará "TAGVERSION" y "Read MP3 Tags" así como el español "Leer Tags de MP3".
	IT	La ricerca per parola chiave viene effettuata nel nome stringa, nella stringa della lingua di default (inglese) e di quella attualmente in uso. La ricerca non distingue le maiuscole/minuscole. Per esempio, ricercando "tag" verranno trovati "TAGVERSION" cosi' come "read MP3 Tags" o l'italiano "Voci multiple nelle Tag".
	NL	De trefwoord zoekmogelijkheid zoekt naar tekst in string namen, de standaard taal strings (Engels) en de huidige taal strings. Het zoeken is niet hoofd- en kleine letter gevoelig. Zoeken naar "tag" zal zowel "TAGVERSION", "Read MP3 Tags" als het Duitse "Frohe Feiertage!" vinden.

PLUGIN_STRINGEDITOR_SEARCH_STRING
	CZ	Vyhledat řetězec:
	DE	Zu suchende Zeichenkette:
	EN	Find string:
	ES	Buscar cadena:
	IT	Cerca la stringa:
	NL	Zoek string:

PLUGIN_STRINGEDITOR_BAD_SEARCH
	DE	Ungültiger Suchausdruck
	EN	Illegal search expression
	IT	Espressione di ricerca non corretta

PLUGIN_STRINGEDITOR_ALL_STRINGS
	DE	Alle Texte
	EN	All String
	IT	Tutte le stringhe

PLUGIN_STRINGEDITOR_NOT_TRANSLATED
	CZ	Chybějící překlady
	DE	Fehlende Übersetzungen
	EN	Missing translations
	ES	Traducciones faltantes
	IT	Traduzioni mancanti
	NL	Missende vertalingen

PLUGIN_STRINGEDITOR_NO_EMPTY_STRINGS
	CZ	Nejsou žádné chybějící překlady.
	DE	Es wurden keine noch nicht übersetzten Texte gefunden.
	EN	There are no translations missing.
	ES	No hay texto sin traducir.
	IT	Non ci sono traduzioni mancanti.
	NL	Er zijn geen missende vertalingen.

PLUGIN_STRINGEDITOR_STRING_NOT_FOUND
	CZ	Řetezec nebyl nalezen!
	DE	Die Zeichenkette wurde nicht gefunden!
	EN	String was not found!
	ES	No se encontró la cadena!
	IT	Stringa non trovata!
	NL	String niet gevonden!

PLUGIN_STRINGEDITOR_FOUND_DESC
	CZ	Po kliknutí na identifikátor popisku, nebo jeho výchozí (anglický) překlad se zobrazí okno pro doplnění vašeho překladu.
	DE	Klicken Sie auf einen Stringnamen oder das englische Original, um die Übersetzung zu bearbeiten.
	EN	Click either the stringname or the english translation to edit your language's value.
	ES	Hacer click sobre el nombre de la cadena o sobre la traducción al inglés, para editar el valor en tu idioma.
	IT	Clicca sia il nome della stringa che la traduzione inglese per modificare il testo nella tua lingua.
	NL	Klik op de stringnaam of de Engelse tekst om je vertaling te wijzigen.

PLUGIN_STRINGEDITOR_ADD_LANGUAGE
	CZ	Přidat jazyk
	DE	Neue Sprache
	EN	Add language
	ES	Añadir idioma
	IT	Aggiungi lingua
	NL	Taal toevoegen

PLUGIN_STRINGEDITOR_ADD_LANGUAGE_DESC
	CZ	Vytvořit nový překlad. Ujistěte se, že nepoužíváte již existující identifikátor jazyka, nebo jméno. Poté co bude překlad přidán, bude automaticky použit pro SlimServer. Budete moci okamžitě přidávat překldy popisků.
	DE	Hier können Sie eine gänzlich neue Übersetzung starten. Achten Sie darauf, weder Kürzel noch Bezeichnung einer bestehenden Übersetzung zu verwenden. Nach dem Erstellen der neuen Spracheinstellungen wird die neu erstellte Sprache für den SlimServer verwendet. Sie können somit gleich mit dem Übersetzen anfangen.
	EN	Create an all new translation. Be sure not to use any existing language identification or name. After you've added the new translation it will automatically be used for your SlimServer. You can immediately start adding translated strings.
	ES	Crear un traducción completamente nueva.  Asegurarse de no utilizar un nombre o  identificación de idioma ya existente. Después de haber añadido una nueva traducción, esta se utilizará automáticamente en tu SlimServer. Se puede empezar a añadir nuevas cadenas traducidas inmediatamente.
	IT	Crea una traduzione completamente nuova. Sii certo di non usare un nome o identificativo esistente. Dopo aver aggiunto la nuova traduzione, sarà usata automaticamente dal tuo Slimserver. Puoi quindi iniziare ad aggiungere subito il testo tradotto.
	NL	Maak een hele nieuwe vertaling. Zorg ervoor dat je geen bestaande taal indentificatie of naam gebruikt. Zodra je de nieuwe taal hebt ingevoerd zal die automatisch gebruikt worden voor je SlimServer. Je kunt direct beginnen met het toevoegen van de vertalingen.

PLUGIN_STRINGEDITOR_ADD_LANGUAGE_ID
	CZ	Dvojpísmenná identifikace jazyka (něco jako 'CZ')
	DE	Das zweiziffrige Kürzel (wie z.B. 'DE')
	EN	The two-letter identification (like eg. 'EN')
	ES	Las dos letras para identificación (por ej. 'ES')
	IT	Identificativo a due lettere (p.es. IT)
	NL	Twee-letterige indentificatie (bijv. 'NL')

PLUGIN_STRINGEDITOR_ADD_LANGUAGE_NAME
	CZ	Jazyk (např. 'Czech')
	DE	Bezeichnung der Sprache (z.B. 'Deutsch')
	EN	Language name (eg. 'English')
	ES	Nombre del idioma (por ej. 'Español')
	IT	Nome lingua (es. 'Italiano')
	NL	Naam van de taal ( bijv. 'Nederlands')

PLUGIN_STRINGEDITOR_ADD_LANGUAGE_CREDITS
	CZ	Přeložil
	DE	Name des Übersetzers
	EN	The translator's name
	ES	Nombre del traductor
	IT	Nome del traduttore
	NL	Naam vertaler

PLUGIN_STRINGEDITOR_LANGUAGE_ALREADY_EXISTS
	CZ	Tento jazyk už existuje
	DE	Die gewünschte Sprache existiert bereits
	EN	This language is already defined
	ES	Este idioma ya ha sido definido.
	IT	Questa lingua e' gia' definita
	NL	Deze taal bestaat al.

PLUGIN_STRINGEDITOR_LANGUAGE_ADDED
	CZ	Tento jazyk byl úspěšně přidán do Vašeho nastavení SlimServeru:
	DE	Die folgende Sprache wurde erfolgreich erstellt:
	EN	The following language was successfully added to your SlimServer configuration:
	ES	El siguiente idioma fue añadido con éxito a la configuración de SlimServer:
	IT	La seguente lingua e' stata aggiunta con successo alla configurazione dello Slimserver:
	NL	De volgende taal was succesvol toegevoegd aan je SlimServer configuratie:

PLUGIN_STRINGEDITOR_SHOW_STRINGS
	CZ	Soubor s přeloženými popisky
	DE	Lokale Änderungen zeigen
	EN	Show custom strings file
	ES	Mostrar archivo adaptado de cadenas de texto
	IT	Mostra le stringhe personalizzate
	NL	Laat je eigen veranderingen zien

PLUGIN_STRINGEDITOR_SHOW_STRINGS_DESC
	CZ	<a href="custom-strings.txt" target="_blank">Toto</a> soubor s Vaším uživatelským překladem. Obsahuje veškeré změny provedené pomocí Editoru popisků.
	DE	<a href="custom-strings.txt" target="_blank">Dies</a> ist ihre aktuelle Strings Datei. Sie enthält alle Änderungen, die Sie bisher mit dem Strings Editor vorgenommen haben.
	EN	<a href="custom-strings.txt" target="_blank">This</a> is your custom strings file. It contains all the changes you did using the Strings Editor.
	ES	<a href="custom-strings.txt" target="_blank">Este</a> es tu archivo adaptado de cadenas. Contiene todos los cambios realizados con el Editor de Cadenas de Texto.
	IT	<a href="custom-strings.txt" target="_blank">Questo</a> e' il file delle stringhe di carattere personalizzate. Contiene tutte le variazioni fatte usando lo String Editor.
	NL	<a href="custom-strings.txt" target="_blank">This</a> is je eigen bestand met eigen vertaling. Alle wijzigingen met String Editor staan erin.

PLUGIN_STRINGEDITOR_SEND_STRINGS
	CZ	Odeslat soubor s popisky
	DE	Strings senden
	EN	Send strings
	ES	Enviar cadenas de texto
	IT	Invia le stringhe di testo
	NL	Verstuur strings

PLUGIN_STRINGEDITOR_SEND_STRINGS_DESC
	CZ	Můžete odeslat Vaše změny (překlad) do SlimDevices. Překlad bude integrován do dalších verzí SlimServeru. Źádné další informace než následující data a Vaše popisky Vám nebudou zaslány. Pouze kopie tohoto mailu Vám bude zaslána pro oveření.
	DE	Sie können ihre Änderungen an den Programmtexten an <a href="http://www.slimdevices.com" target="_new">SlimDevices</a> schicken. Die Texte können so in zukünftigen Releases integriert werden. Ausser der Textdatei werden nur die im folgenden anzugebenden Informationen weitergeleitet. Eine Kopie der versendeten Nachricht wird ihnen zugestellt.
	EN	You can send your changes to <a href="http://www.slimdevices.com" target="_new">SlimDevices</a>. They will be integrated with a releases. No other information than the following data and your strings file will be sent. A copy of the mail will be sent to you as a confirmation.
	ES	Se pueden enviar los cambios a <a href="http://www.slimdevices.com" target="_new">SlimDevices</a>. Se integrarán a las próximas actualizaciones. No hace falta más informacíon que la siguiente, para que tu archivo sea enviado.  Una copia te será enviada por correo, para tu confirmación.
	IT	Puoi inviare le modifiche alla Slimdevices. Esse verranno inserite nelle nuove versioni. Nessun altra informazione, ad eccezione dei seguenti dati e la tua stringa di dati, sara' inviata. Una copia della mail ti verra' inviata per conferma.
	NL	Je kunt je veranderingen sturen naar <a href="http://www.slimdevices.com" target="_new">SlimDevices</a>. Ze zullen worden geïntegreerd in de Software. Geen andere informatie dan de ondestaande gegevens en het strings bestand worden verstuurd. Een kopie van de mail zal naar jou worden verstuurd als confirmatie.

PLUGIN_STRINGEDITOR_SEND_NAME
	CZ	Jméno:
	DE	Name:
	EN	Name:
	ES	Nombre:
	NL	Naam:

PLUGIN_STRINGEDITOR_SEND_MAIL
	CZ	email:
	DE	Mail-Adresse:
	EN	Mail address:
	ES	Dirección de correo electrónico:
	NL	e-mail adres:

PLUGIN_STRINGEDITOR_SEND_COMMENT
	CZ	Komentář:
	DE	Kommentar:
	EN	Comment:
	ES	Comentario:
	NL	Commentaar:

PLUGIN_STRINGEDITOR_SEND_FILE
	CZ	Odeslat soubor popisků
	DE	Texte schicken
	EN	Send strings
	ES	Enviar cadenas de texto
	IT	Invia le stringhe di testo
	NL	Verstuur strings

PLUGIN_STRINGEDITOR_THANK_YOU
	CZ	Děkujeme velice za pomoc! Potvrzení bude odesláno na Vaši adresu během pár minut.
	DE	Vielen Dank für die Bemühungen! Die Bestätigungsmail mit ihren Änderungen wird in den nächsten Minuten an ihre Adresse geschickt.
	EN	Thank you very much for your contribution! The confirmation will be sent to your address in a few minutes.
	ES	Muchísimas gracias por tu contribución! La confirmación será enviada a tu dirección en unos pocos minutos.
	NL	Bedankt voor je bijdrage! De confirmatie wordt over enige ogenblikken verstuurd naar je e-mail adres.

PLUGIN_STRINGEDITOR_VERIFY_MAIL
	CZ	Prosím zkontrolujte své jméno a adresu. Bez platných hodnot nebude Váš překlad použit! Děkujeme za pochopení.
	DE	Bitte überprüfen Sie Name und Mail-Adresse. Ohne deren Angabe werden die Daten nicht verwertet. Danke fürs Verständnis!
	EN	Please verify name and mail address. Without them your work can't be used. Thank you for your comprehension!
	ES	Por favor, verificar el nombre y la direción de correo. Sin esa información tu trabajo no podrá ser utilizado. Gracias por tu comprensión!
	NL	Controleer je naam en e-mail adres. Zonder kan je werk niet gebruikt worden. Bedankt voor je begrip.

PLUGIN_STRINGEDITOR_SEND_ERROR
	CZ	Chyba během odesílání souboru. Prosím zkuste to znovu později. Děkujeme za pochopení.
	DE	Beim Upload der Daten ist ein Fehler aufgetreten. Bitte versuchen Sie es später nocheinmal. Danke fürs Verständnis!
	EN	There was an error when uploading the file. Please try again later. Thank you for your comprehension!
	ES	Hubo un error al querer enviar el archivo. Por favor, intenta más tarde. Gracias por la comprensión!
	NL	Er is een fout opgetreden tijdens het verzenden van het bestand. Probeer het later nog eens. Bedankt voor het begrip!

PLUGIN_STRINGEDITOR_RESET
	CZ	Výchozí popisky
	DE	Strings zurücksetzen
	EN	Reset strings
	ES	Reestablecer cadenas
	IT	Ripristina stringhe
	NL	Strings resetten

PLUGIN_STRINGEDITOR_RESET_DESC
	CZ	Tato volba odstraní všechny uživatelské překlady popisků. Pouze defaultní jazyky, instalované spolu se SlimServerem budou dostupné. Prosím klikněte na tlačítko, pokud souhlasíte s provedením akce.
	DE	Diese Funktion löscht alle ihre eigenen Übersetzungen und verwendet nur noch die Standardwerte der SlimServer Installation. Bitte drücken Sie "Löschen", wenn Sie damit einverstanden sind.
	EN	This will remove all your custom translations and strings. Only the default values installed with SlimServer will be used. Please press the button if you agree.
	ES	Esto removerá todas tus traducciones y cadenas adaptadas. Solo se utilizarán los valores por defecto de SlimServer. Por favor, presiona el botón si estás de acuerdo.
	IT	Verranno rimosse tutte le stringhe delle traduzioni personali ed usate solo le voci standard installate con lo Slimserver. Premi il bottone se sei d'accordo.
	NL	Dit zal al je aangepaste strings verwijderen. Alleen de standaard waarden van bij SlimServer ge&iuml;nstalleerd zullen worden gebruikt. Druk op de toets als je verder wilt.

PLUGIN_STRINGEDITOR_NO_FILE
	CZ	Nebyl nalezen žádný soubor s uživatelským překladem popisků.
	DE	Es wurde keine Datei mit personalisierten Übersetzungen gefunden!
	EN	No file with custom strings or translations has been found.
	ES	No se ha encontrado un archivo con cadenas adaptadas o traducidas.
	NL	Er is geen bestand met de aangepaste strings gevonden.

PLUGIN_STRINGEDITOR_EMPTY_FILE
	CZ	# Váš soubor popisků je prázdný
	DE	# ihre personalisierte Text-Datei ist leer
	EN	# your custom strings file is empty
	ES	# Tu archivo adaptado de cadenas de texto está vacío
	IT	# il file di stringhe personali e' vuoto
	NL	# Je bestand met aangepaste strings is leeg

PLUGIN_STRINGEDITOR_FILE_REMOVED
	CZ	Váš překlad byl odstraněn.
	DE	Die personalisierten Übersetzungen wurden entfernt.
	EN	Custom strings have been removed.
	ES	Las cadenas adaptados han sido removidas.
	IT	Le stringhe personali sono state rimosse.
	NL	De aangepaste strings zijn verwijderd.

PLUGIN_STRINGEDITOR_MODE
	CZ	Mód 'překládání'
	DE	Übersetzermodus
	EN	Translator mode
	ES	Modo Traducción
	IT	Modalita' traduttore
	NL	Vertaal mode

PLUGIN_STRINGEDITOR_MODE_ON
	CZ	Mod 'překládání' byl zapnut.
	DE	Der Übersetzermodus wurde aktiviert.
	EN	Translator mode has been activated.
	ES	El Modo Traducción ha sido activado.
	NL	De vertaal mode is geactiveerd.

PLUGIN_STRINGEDITOR_MODE_OFF
	CZ	Mod 'překládání' byl vypnut.
	DE	Der Übersetzermodus wurde deaktiviert.
	EN	Translator mode has been deactivated.
	ES	El Modo Traducción ha sido desactivado.
	NL	De vertaalmode is gedeactiveerd.

PLUGIN_STRINGEDITOR_MODE_DESC
	CZ	V módu 'překládání' SlimServer dopní jméno popisku ve složených závorkách (např. "Tento text nebyl přeložen {NON_TRANSLATED_TEXT}". Tato volba Vám pomůže s orientací v popiskách, ale znepřehlední grafický výstup. Proto ji použijte tehdy, když budete potřebovat pomoci s vylepšením překladu popisků SlimServeru.
	DE	Im Übersetzermodus hängt Slimserver hinter allen Texten, die noch nicht in der aktuellen Sprache vorliegen, den Namen der fehlenden Zeichenkette in geschweiften Klammern an (z.B. "This is non translated text {NON_TRANSLATED_TEXT}"). Dies hilft Übersetzern bei ihrer Arbeit, kann jedoch unter Umständen den Bildschirm etwas unübersichtlich machen. Aktivieren Sie diese Option daher nur, wenn Sie an der Übersetzung des Slimservers arbeiten wollen.
	EN	While in translator mode Slimserver will add the stringname of missing strings in curly braces (eg. "Dieser Text ist nicht übersetzt {NON_TRANSLATED_TEXT}"). This will help translators do their work, but can clutter your screen. Only use this option, if you want to help improve the Slimserver's translation.
	ES	Cuando está en Modo Traducción, SlimServer añadirá el nombre de las cadenas faltantes entre llaves (por ejemplo: "RSS News Ticker {PLUGIN_RSSNEWS}" ). Este ayudará a los traductores a realizar su trabajo, aunque puede llenar demasiado la pantalla. Utilizar esta opción solo si se quiere ayudar a mejorar la traducción de SlimServer.
	IT	Quando è in modalità traduttore lo Slimserver aggiungerà il nome della stringa mancante in parentesi graffe (es. "Questo testo non è tradotto {NON_TRANSLATED_TEXT}"). Ciò aiuterà i traduttori nel loro lavoro ma renderà confuso lo schermo. Usa questa opzione solo se vuoi aiutarti nella traduzione dello Slimserver.
	NL	De translater mode zal de stringnaam van missende strings tussen accolades zetten (bijvoorbeeld "Deze tekst is niet vertaald{NON_TRANSLATED_TEXT}. Dit helpt vertalers om hun werk te doen maar het maakt een warboel van je scherm. Gebruik deze optie alleen tijdens het vertalen.

PLUGIN_STRINGEDITOR_NOPLUGINS
	CZ	Ignorovat popisky pluginů
	DE	Texte aus Plugins ignorieren
	EN	Ignore strings contained in plugins
	ES	Ignorar cadenas contenidas en plugins
	IT	Ignora le stringhe contenute nei plugins
	NL	Negeer strings in plugins

PLUGIN_STRINGEDITOR_NOPLUGINS_ON
	CZ	Popisky pluginů nejsou prohledávány.
	DE	Texte aus Plugins werden bei der Suche <em>nicht</em> berücksichtigt.
	EN	Strings contained in plugins are ignored when searching.
	ES	Las cadenas contenidas en los plugins se ignoran en la búsqueda.
	NL	Strings in plugins worden genegeerd bij het zoeken.

PLUGIN_STRINGEDITOR_NOPLUGINS_OFF
	CZ	Popisky pluginů jsou prohledávány.
	DE	Texte aus Plugins werden bei der Suche berücksichtigt.
	EN	Strings contained in plugins are respected when searching.
	ES	Las cadenas contenidas en los plugins se incluyen en la búsqueda.
	NL	Strings in plugins worden doorzocht bij het zoeken.

PLUGIN_STRINGEDITOR_NOPLUGINS_DESC
	CZ	Pro zlepšení přehlednosti výsledků vyhledávání je možné skrýt popisky, které patří k pluginům. Tuto volbu použijte tehdy, pokud chcete pracovat pouze s základními popisky SlimServeru.
	DE	Um die Übersicht bei den Suchresultaten zu erhalten können Sie Texte aus Plugins ausfiltern lassen.
	EN	To improve the clarity of search results you can hide strings, that are contained in plugins. Thus you'll only work on the main strings.
	ES	Para mejorar la claridad de los resultados de búsqueda, se puede ocultar las cadenas que están contenidas en plugins. De esta forma solo se verán las cadenas principales.
	IT	Per rendere più chiare le ricerche puoi nascondere le stringhe contenute nei plugins. Così lavorerai solo sulle stringhe principali.
	NL	Om de duidelijkheid bij het zoeken kunnen de strings in plugins verborgen worden. Dan werk je alleen op de hoofdstrings.

PLUGIN_STRINGEDITOR_DISPLAY_TOO_SMALL
	CZ	Měli byste raději použít webové rozhranní pro editování textů, Váš displej na přehrávači bude pro tuto činnost asi dost malý ;-)
	DE	Bitte verwenden Sie das Web-Interface dieses Plugins, denn das Display ihres Players ist zum Textbearbeiten offensichtlich einfach ein wenig zu klein ;-)
	EN	You'd rather use this plugin's web interface for text editing, as your player's display obviously is just a little bit too small ;-)
	ES	Es conveniente utilizar la interfaz web de este plugin para editar texto, ya que la pantalla del reproductor es levemente más pequeña ;-)
	NL	Je kunt beter de plugin interface gebruiken voor het aanpassen omdat het scherm van je speler iets te klein is ;-)

PLUGIN_STRINGEDITOR_CHANGELOG
	CZ	Změny ve verzích
	DE	Changelog
	EN	Changelog
	ES	Log de cambios
	IT	Elenco modifiche
	NL	Wijzigingen

PLUGIN_STRINGEDITOR_CHANGELOG_DESC
	CZ	Toto je zjednodušená verze změn souboru <a href="http://svn.slimdevices.com/trunk/server/strings.txt" target="_blank">strings.txt</a> (changelog), jehož zdroj je <a href="http://svn.slimdevices.com/" target="_blank">http://svn.slimdevices.com/</a>.  Po kliknutí se odkaz otevře v samostatném okně.
	DE	Dies ist der Changelog für <a href="http://svn.slimdevices.com/trunk/server/strings.txt" target="_blank">strings.txt</a> Datei auf <a href="http://svn.slimdevices.com/" target="_blank">http://svn.slimdevices.com/</a>.<br> Die Links erlauben das Anzeigen von Veränderungen an den verschiedenen Versionen. Sie werden in einem neuen Fenster geöffnet.
	EN	This is a simplified version the <a href="http://svn.slimdevices.com/trunk/server/strings.txt" target="_blank">strings.txt</a>'s changelog taken from <a href="http://svn.slimdevices.com/" target="_blank">http://svn.slimdevices.com/</a>.<br> A click on a link will open the diff in a new window.
	ES	Esta es una versión simplificada del log de cambios de  <a href="http://svn.slimdevices.com/trunk/server/strings.txt" target="_blank">strings.txt</a> tomado de http://svn.slimdevices.com/.  Un click en el link mostrará las diferencias en una nueva ventana
	IT	Questa e' una versione semplificata delle variazioni apportate al file <a href="http://svn.slimdevices.com/trunk/server/strings.txt" target="_blank">string.txt</a> presa da http://svn.slimdevices.com/.  Un click su un collegamento mostrera' la variazione in una nuova finestra.
	NL	Dit is een gesimpliceerde versie van <a href="http://svn.slimdevices.com/trunk/server/strings.txt" target="_blank">strings.txt</a> overzicht van wijzigingen van <a href="http://svn.slimdevices.com/" target="_blank">http://svn.slimdevices.com/</a>.<br> Een klik op een link opent de diff in een nieuw venster.

PLUGIN_STRINGEDITOR_WARNING_PERL56
	DE	<em>Achtung!</em> Sie scheinen noch Perl 5.6 zu verwenden. Die mit dieser Perl-Version erstellten Änderungen können u.U. wegen mangelhafter Unterstützung für UTF8 fehlerhaft sein! Bitte verwenden Sie Perl 5.8.1 oder aktueller mit dem StringEditor.
	EN	<em>Please note:</em> you seem to still be using perl 5.6. Due to limited utf8 support in this version some of the changes you do might be incomplete or unusable if they use non latin-1 characters! Please update to perl 5.8.1 or later with this plugin.
	ES	<em>Atención por favor</em>: parece que se está usando aún perl 5.6. Debido al soporte limitado para utf8 en esta versión, algunos de los cambios que se realicen pueden quedar incompletos o inusables si involucran caractéres que no sean latin-1.! Por favor actualizar a perl 5.8.1 o posterior con este plugin.
	NL	<em>Belangrijk:</em> Het lijkt erop dat je nog steeds perl 5.6 gebruikt. Door gelimiteerde utf8 ondersteuning in deze versie worden sommige van de wijzigingen incompleet als je speciale karakters gebruikt. Ga over naar perl 5.8.1 of nieuwer met deze plugin.^;
};
1;
